<?php
/**
 * Theme customizer options
 *
 * @package e-shopper
 * @since 3.0.0
 */

/**
 * Registers the customizer layout options.
 *
 * @param  WP_Customize_Manager $wp_customize The WordPress customizer manager instance.
 * @return void
 */
function e_shopper_customize_register_layout( $wp_customize ) {
	/**
	 * == Layout Panel ==
	 *
	 * Adds the 'Layout' panel.
	 */
	$wp_customize->add_panel(
		'e_shopper_layout',
		array(
			'title'    => esc_html__( 'Layout', 'e-shopper' ),
			'priority' => 25,
		)
	);

	/**
	 * == Header Layout Section ==
	 *
	 * Adds 'Header Layout' section.
	 */
	$wp_customize->add_section(
		'e_shopper_layout_header',
		array(
			'title' => esc_html__( 'Header', 'e-shopper' ),
			'panel' => 'e_shopper_layout',
		)
	);

	/**
	 * Adds the 'Full width header?' option.
	 */
	$wp_customize->add_setting(
		'e_shopper_full_width_header',
		array(
			'default'           => false,
			'sanitize_callback' => 'e_shopper_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'e_shopper_full_width_header',
			array(
				'label'   => esc_html__( 'Full width?', 'e-shopper' ),
				'section' => 'e_shopper_layout_header',
				'type'    => 'checkbox',
			)
		)
	);

	$header_layout_options = e_shopper_get_header_layout_options();
	$wp_customize->add_setting(
		'e_shopper_header_layout',
		array(
			'default'           => key( $header_layout_options ),
			'sanitize_callback' => 'e_shopper_sanitize_header_layout',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'e_shopper_header_layout',
			array(
				'label'   => esc_html__( 'Layout', 'e-shopper' ),
				'section' => 'e_shopper_layout_header',
				'type'    => 'select',
				'choices' => $header_layout_options,
			)
		)
	);

	/**
	 * == Content Layout Section ==
	 *
	 * Adds the 'Content' layout section.
	 */
	$wp_customize->add_section(
		'e_shopper_layout_content',
		array(
			'title' => esc_html__( 'Content', 'e-shopper' ),
			'panel' => 'e_shopper_layout',
		)
	);

	/**
	 * Adds the 'Sidebar' layout option.
	 */
	$sidebar_layout_options = e_shopper_get_sidebar_layout_options();
	$wp_customize->add_setting(
		'e_shopper_sidebar_layout',
		array(
			'default'           => key( $sidebar_layout_options ),
			'sanitize_callback' => 'e_shopper_sanitize_sidebar_layout',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'e_shopper_sidebar_layout',
			array(
				'label'   => esc_html__( 'Sidebar', 'e-shopper' ),
				'section' => 'e_shopper_layout_content',
				'type'    => 'select',
				'choices' => $sidebar_layout_options,
			)
		)
	);

	/**
	 * == Blog Layout Section ==
	 *
	 * Adds the 'Blog' layout section.
	 */
	$wp_customize->add_section(
		'e_shopper_layout_blog',
		array(
			'title' => esc_html__( 'Blog', 'e-shopper' ),
			'panel' => 'e_shopper_layout',
		)
	);

	/**
	 * Adds the 'Excerpt Length' option.
	 */
	$wp_customize->add_setting(
		'e_shopper_excerpt_length',
		array(
			'default'           => 30,
			'sanitize_callback' => 'absint',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'e_shopper_excerpt_length',
			array(
				'active_callback' => 'e_shopper_has_post_excerpt',
				'label'           => esc_html__( 'Excerpt Length in Words', 'e-shopper' ),
				'section'         => 'e_shopper_layout_blog',
				'type'            => 'range',
				'input_attrs'     => array(
					'min'  => 10,
					'max'  => 50,
					'step' => 1,
				),
			)
		)
	);

	/**
	 * Adds the 'More link' text option.
	 */
	$wp_customize->add_setting(
		'e_shopper_excerpt_more',
		array(
			'default'           => esc_html__( 'Read more', 'e-shopper' ),
			'sanitize_callback' => 'sanitize_text_field',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'e_shopper_excerpt_more',
			array(
				'active_callback' => 'e_shopper_has_post_excerpt',
				'label'           => esc_html__( 'More Link Text', 'e-shopper' ),
				'section'         => 'e_shopper_layout_blog',
			)
		)
	);

	/**
	 * == Footer Layout Section ==
	 *
	 * Adds the 'Footer' layout section.
	 */
	$wp_customize->add_section(
		'e_shopper_layout_footer',
		array(
			'title' => esc_html__( 'Footer', 'e-shopper' ),
			'panel' => 'e_shopper_layout',
		)
	);

	/**
	 * Adds the custom 'Copyright' text option.
	 */
	$wp_customize->add_setting(
		'e_shopper_copyright',
		array(
			'default'           => e_shopper_get_copyright_text(),
			'sanitize_callback' => 'wp_kses_data',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'e_shopper_copyright',
			array(
				'label'   => esc_html__( 'Copyright Text', 'e-shopper' ),
				'section' => 'e_shopper_layout_footer',
				'type'    => 'textarea',
			)
		)
	);
}
add_action( 'customize_register', 'e_shopper_customize_register_layout' );

/**
 * Sanitizes sidebar layout options.
 *
 * @param  string $value The input value.
 * @return string        The sanitized sidebar layout option.
 */
function e_shopper_sanitize_sidebar_layout( $value ) {
	$sidebar_layout_options = e_shopper_get_sidebar_layout_options();

	if ( ! array_key_exists( $value, $sidebar_layout_options ) ) {
		$value = key( $sidebar_layout_options );
	}

	return $value;
}

/**
 * Returns true on templates that contain post excerpt.
 *
 * @return boolean
 */
function e_shopper_has_post_excerpt() {
	return ( is_home() || is_archive() || is_search() );
}

/**
 * Returns the theme's sidebar layout options.
 *
 * @return array
 */
function e_shopper_get_sidebar_layout_options() {
	$layout_options = array(
		'default' => esc_html__( 'Right Sidebar', 'e-shopper' ),
		'left'    => esc_html__( 'Left Sidebar', 'e-shopper' ),
		'none'    => esc_html__( 'No Sidebar', 'e-shopper' ),
	);

	return apply_filters( 'e_shopper_sidebar_layout_options', $layout_options );
}

/**
 * Returns the default copyright text.
 *
 * @return array
 */
function e_shopper_get_copyright_text() {
	/* Translators: %1$s for year, %2$s for site title. */
	return sprintf( esc_html__( 'Copyright &copy; %1$s %2$s', 'e-shopper' ), esc_html( date( 'Y' ) ), esc_html( get_bloginfo( 'name' ) ) );
}

/**
 * Sanitizes header layout options.
 *
 * @param  string $value The input value.
 * @return string        The sanitized header layout options.
 */
function e_shopper_sanitize_header_layout( $value ) {
	$header_layout_options = e_shopper_get_header_layout_options();

	if ( ! array_key_exists( $value, $header_layout_options ) ) {
		$value = key( $header_layout_options );
	}

	return $value;
}

/**
 * Returns the theme's header layout options.
 *
 * @return array
 */
function e_shopper_get_header_layout_options() {
	$header_layouts = array(
		'default'   => esc_html__( 'Default', 'e-shopper' ),
		'ecommerce' => esc_html__( 'Ecommerce', 'e-shopper' ),
	);

	return apply_filters( 'e_shopper_header_layout_options', $header_layouts );
}
