<?php
/**
 * Theme typography options.
 *
 * @package e-shopper
 * @since 3.0.0
 */

/**
 * Registers the customizer typography options.
 *
 * @param  WP_Customize_Manager $wp_customize The WordPress customizer manager instance.
 * @return void
 */
function e_shopper_customize_register_typography( $wp_customize ) {
	/**
	 * == Typography Section ==
	 *
	 * Adds the typography section.
	 */
	$wp_customize->add_section(
		'e_shopper_typography',
		array(
			'title'    => esc_html__( 'Typography', 'e-shopper' ),
			'priority' => 35,
		)
	);

	// Add select font pair option.
	$font_options = e_shopper_get_font_options();
	$wp_customize->add_setting(
		'e_shopper_typography_fonts',
		array(
			'default'           => key( $font_options ),
			'sanitize_callback' => 'e_shopper_sanitize_fonts',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'e_shopper_typography_fonts',
			array(
				'label'   => esc_html__( 'Heading &amp; Text Fonts', 'e-shopper' ),
				'section' => 'e_shopper_typography',
				'type'    => 'select',
				'choices' => $font_options,
			)
		)
	);
}
add_action( 'customize_register', 'e_shopper_customize_register_typography' );

/**
 * Returns the Google font pairs to use in this theme.
 *
 * @return array
 */
function e_shopper_get_fonts() {
	$fonts = array(
		'merriweather_lato'    => array(
			'name'     => esc_html__( 'Merriweather &amp; Lato', 'e-shopper' ),
			'families' => array(
				'heading' => 'Merriweather:400,700',
				'body'    => 'Lato:400,400i,700,700i',
			),
		),
		'poppins_roboto'       => array(
			'name'     => esc_html__( 'Poppins &amp; Roboto', 'e-shopper' ),
			'families' => array(
				'heading' => 'Poppins:400,700',
				'body'    => 'Roboto:400,400i,700,700i',
			),
		),
		'montserrat_ptserif'   => array(
			'name'     => esc_html__( 'Montserrat &amp; PT Serif', 'e-shopper' ),
			'families' => array(
				'heading' => 'Montserrat:400,700',
				'body'    => 'PT Serif:400,400i,700,700i',
			),
		),
		'playfairdisplay_muli' => array(
			'name'     => esc_html__( 'Playfair Display &amp; Muli', 'e-shopper' ),
			'families' => array(
				'heading' => 'Playfair Display:400,700',
				'body'    => 'Muli:400,400i,700,700i',
			),
		),
	);

	return apply_filters( 'e_shopper_fonts', $fonts );
}

/**
 * Returns the Google font pairs choices for customizer select control.
 *
 * @return array
 */
function e_shopper_get_font_options() {
	$font_pairs = e_shopper_get_fonts();
	$choices    = array();

	foreach ( $font_pairs as $pair => $args ) {
		$choices[ $pair ] = $args['name'];
	}

	return $choices;
}

/**
 * Returns the theme's selected font pair.
 *
 * @return array
 */
function e_shopper_get_selected_fonts() {
	$fonts          = e_shopper_get_fonts();
	$selected_fonts = get_theme_mod( 'e_shopper_typography_fonts', key( $fonts ) );

	$font_families = $fonts[ $selected_fonts ]['families'];
	$heading_font  = explode( ':', $font_families['heading'] );
	$body_font     = explode( ':', $font_families['body'] );

	return array(
		'heading' => $heading_font[0],
		'body'    => $body_font[0],
	);
}

/**
 * Filters theme font families.
 *
 * @return array
 */
function e_shopper_custom_font_families() {
	$fonts          = e_shopper_get_fonts();
	$selected_fonts = get_theme_mod( 'e_shopper_typography_fonts', key( $fonts ) );

	return $fonts[ $selected_fonts ]['families'];
}
add_filter( 'e_shopper_font_families', 'e_shopper_custom_font_families' );

/**
 * Sanitizes the font pair.
 *
 * @param int $value to return.
 * @return float The sanitized font pair.
 */
function e_shopper_sanitize_fonts( $value ) {
	$font_pairs = e_shopper_get_font_options();

	if ( ! array_key_exists( $value, $font_pairs ) ) {
		$value = key( $font_pairs );
	}

	return $value;
}
